@@ -570,6 +570,11 @@ def share_access_create(context, values):
     return IMPL.share_access_create(context, values)
 
 
+def share_access_update(context, access_id, values):
+    """Update access to share."""
+    return IMPL.share_access_update(context, access_id, values)
+
+
 def share_access_get(context, access_id):
     """Get share access rule."""
     return IMPL.share_access_get(context, access_id)
@@ -1297,12 +1302,12 @@ def share_server_get_all_by_host_and_share_subnet_valid(
     )
 
 
-def share_server_get_all_by_host_and_share_subnet(
-    context, host, share_subnet_id,
+def share_server_get_all_by_host_and_or_share_subnet(
+    context, host=None, share_subnet_id=None,
 ):
-    """Get share server DB records by host and share net."""
-    return IMPL.share_server_get_all_by_host_and_share_subnet(
-        context, host, share_subnet_id,
+    """Get share server DB records by host and/or share net."""
+    return IMPL.share_server_get_all_by_host_and_or_share_subnet(
+        context, host=host, share_subnet_id=share_subnet_id,
     )
 
 
