@@ -218,6 +218,7 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
+                        'share_replicas_migration_support': False
                     },
                 }, {
                     'name': 'host2@back1#BBB',
@@ -252,6 +253,7 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
+                        'share_replicas_migration_support': False
                     },
                 }, {
                     'name': 'host2@back2#CCC',
@@ -286,6 +288,7 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
+                        'share_replicas_migration_support': False
                     },
                 },
             ]
@@ -342,6 +345,7 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
+                        'share_replicas_migration_support': False
                     },
                 }, {
                     'name': 'host2@BBB#pool2',
@@ -377,6 +381,7 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
+                        'share_replicas_migration_support': False
                     },
                 }, {
                     'name': 'host3@CCC#pool3',
@@ -412,6 +417,7 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
+                        'share_replicas_migration_support': False
                     },
                 }, {
                     'name': 'host4@DDD#pool4a',
@@ -447,6 +453,7 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
+                        'share_replicas_migration_support': False
                     },
                 }, {
                     'name': 'host4@DDD#pool4b',
@@ -482,6 +489,7 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
+                        'share_replicas_migration_support': False
                     },
                 },
             ]
@@ -550,6 +558,7 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
+                        'share_replicas_migration_support': False
                     },
                 }, {
                     'name': 'host2@back1#BBB',
@@ -584,6 +593,7 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
+                        'share_replicas_migration_support': False
                     },
                 },
             ]
@@ -646,6 +656,7 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
+                        'share_replicas_migration_support': False,
                     },
                 },
             ]
